@@ -9,10 +9,10 @@
 #' @param .data A dataset to use, if none are specified than
 #' the original dataset passed to `e_charts` is used.
 #' @param value The column to map to the parameter.
-#' 
+#'
 #' @section Functions:
-#' 
-#' - `e_add_nested`: Adds nested data, e.g.: 
+#'
+#' - `e_add_nested`: Adds nested data, e.g.:
 #' `e_add_nested("itemStyle", color, fontBold)` creates
 #' `\{itemStyle: \{color: 'red', fontBold: 'bold'\}\}`.
 #' - `e_add_unnested`: Adds unnested data, e.g.:
@@ -66,7 +66,7 @@
 #'     show,
 #'     fontStyle
 #'   )
-#' 
+#'
 #' @name nesting
 #' @export
 e_add <- function(e, param, ..., .serie = NULL, .data = NULL) {
@@ -75,7 +75,7 @@ e_add <- function(e, param, ..., .serie = NULL, .data = NULL) {
 }
 
 #' @rdname nesting
-#' @export 
+#' @export
 e_add_nested <- function(e, param, ..., .serie = NULL, .data = NULL) {
   if (missing(e) || missing(param)) {
     stop("missing e or param", call. = FALSE)
@@ -98,11 +98,19 @@ e_add_nested <- function(e, param, ..., .serie = NULL, .data = NULL) {
         for(k in seq_along(e$x$opts$series)){
           if(!is.null(.serie) && .serie != k)
             next
+          if(!is.numeric(e$x$opts$series[[k]]$data[[j]])){
         e$x$opts$series[[k]]$data[[j]][[param]] <- data[[j]]
+          } else {
+            # If polar, 'itemStyle' may be in a different location - this fixes that.
+            e$x$opts$series[[k]]$data[[j]] <- c(
+              list(value = e$x$opts$series[[k]]$data[[j]]),
+              stats::setNames(list(data[[j]]), param)
+            )
+          }
         }
       } else {
         for(k in seq_along(e$x$opts$options[[i]]$series)){
-          if(!is.null(.serie) && .serie != k) 
+          if(!is.null(.serie) && .serie != k)
             next
           e$x$opts$options[[i]]$series[[k]]$data[[j]][[param]] <- data[[j]]
         }
@@ -113,7 +121,7 @@ e_add_nested <- function(e, param, ..., .serie = NULL, .data = NULL) {
 }
 
 #' @rdname nesting
-#' @export 
+#' @export
 e_add_unnested <- function(e, param, value, .serie = NULL, .data = NULL) {
   if (missing(e) || missing(param) || missing(value)) {
     stop("missing e, param, or value", call. = FALSE)
@@ -126,7 +134,7 @@ e_add_unnested <- function(e, param, value, .serie = NULL, .data = NULL) {
 
   for (i in seq_along(ds)) {
     data <- ds[[i]] |>
-      dplyr::pull({{ value }}) |> 
+      dplyr::pull({{ value }}) |>
       unname()
 
     for (j in seq_along(data)) {
@@ -134,7 +142,15 @@ e_add_unnested <- function(e, param, value, .serie = NULL, .data = NULL) {
         next
 
       if (!e$x$tl) {
+        if(!is.numeric(e$x$opts$series[[i]]$data[[j]])){
         e$x$opts$series[[i]]$data[[j]][[param]] <- data[j]
+        } else {
+          # If polar, 'itemStyle' may be in a different location - this fixes that.N
+          e$x$opts$series[[i]]$data[[j]] <- c(
+            list(value = e$x$opts$series[[i]]$data[[j]]),
+            stats::setNames(list(data[[j]]), param)
+          )
+        }
       } else {
         for(k in seq_along(e$x$opts$options[[i]]$series)){
           e$x$opts$options[[i]]$series[[k]]$data[[j]][[param]] <- data[j]
@@ -144,3 +160,56 @@ e_add_unnested <- function(e, param, value, .serie = NULL, .data = NULL) {
   }
   e
 }
+
+
+#' Insert binded data
+#'
+#' Utility function to attach an existing column(s) from your data to an existing series
+#'
+#' @inheritParams e_bar
+#' @param .serie Serie's index to add the data.
+#' @param .data Column names for the new data.
+#'
+#' @details This inserts new data into a series's values which allows for use in mapping things like e_visual_map 
+#' or tooltip parameters. This function also works when using timelines.
+#'
+#' @examples
+#' mtcars |>
+#'  e_charts(mpg) |>
+#'  e_scatter(wt, scale = e_scale) |>
+#'  e_insert_data(.serie = 1, .data = "qsec") |>
+#'  e_visual_map(qsec, scale = e_scale, dimension = 2) |> 
+#'  e_tooltip(trigger = "item", 
+#'            formatter = htmlwidgets::JS("function(params) {
+#'                                        return 'mpg: ' + params.value[0] + 
+#'                                        '<br />wt: ' + params.value[1] +
+#'                                        '<br />qsec: ' + params.value[2];
+#'                                        }")
+#'  ) 
+#'
+#' @name e_insert_data
+#' @export
+e_insert_data <- function(e, .serie, .data){
+  if(!e$x$tl){
+    for(i in seq_along(e$x$data)) {
+      bind <- e$x$data[[i]] |>
+        dplyr::select(dplyr::all_of(.data)) |>
+        unname() |>
+        unlist()
+      for(j in seq_along(e$x$opts$series[[.serie]]$data)){
+        e$x$opts$series[[.serie]]$data[[j]]$value <- append(e$x$opts$series[[.serie]]$data[[j]]$value, bind[j])
+      }
+    }
+  } else {
+    for(i in seq_along(e$x$data)) {
+      bind <- e$x$data[[i]] |>
+        dplyr::select(dplyr::all_of(.data)) |>
+        unname() |>
+        unlist()
+      for(j in seq_along(e$x$opts$options[[i]]$series[[.serie]]$data)){
+        e$x$opts$options[[i]]$series[[.serie]]$data[[j]]$value <- append(e$x$opts$options[[i]]$series[[.serie]]$data[[j]]$value, bind[j])
+      }
+    }
+  }
+  e
+}
