@@ -42,7 +42,7 @@
 #' @export
 e_timeline_opts <- function(e, axis_type = "category", ...) {
   if (missing(e)) {
-    stop("missing e", call. = FALSE)
+    stop("must pass e", call. = FALSE)
   }
 
   if (!e$x$tl) {
@@ -60,7 +60,7 @@ e_timeline_opts <- function(e, axis_type = "category", ...) {
 #' @export
 e_timeline_serie <- function(e, ..., index = 1) {
   if (missing(e)) {
-    stop("missing e", call. = FALSE)
+    stop("must pass e", call. = FALSE)
   }
 
   args <- list(...)
@@ -69,8 +69,8 @@ e_timeline_serie <- function(e, ..., index = 1) {
     stop("no arguments passed", call. = FALSE)
   }
 
-  for (i in 1:length(e$x$opts$options)) {
-    for (j in 1:length(args)) {
+  for (i in seq_along(e$x$opts$options)) {
+    for (j in seq_along(args)) {
       if (!length(e$x$opts$options[[i]][[names(args)[j]]]) < index) {
         e$x$opts$options[[i]][[names(args)[j]]][[index]] <- list()
       }
@@ -85,7 +85,7 @@ e_timeline_serie <- function(e, ..., index = 1) {
 #' @export
 e_timeline_on_serie <- function(e, ..., serie_index) {
   if (missing(e) || missing(serie_index)) {
-    stop("missing e or serie_index", call. = FALSE)
+    stop("must pass e or serie_index", call. = FALSE)
   }
 
   args <- list(...)
@@ -94,8 +94,8 @@ e_timeline_on_serie <- function(e, ..., serie_index) {
     stop("no arguments passed", call. = FALSE)
   }
 
-  for (i in 1:length(e$x$opts$options)) {
-    for (j in 1:length(args)) {
+  for (i in seq_along(e$x$opts$options)) {
+    for (j in seq_along(args)) {
       if (!length(e$x$opts$options[[i]]$series[[serie_index]][[names(args)[j]]]) < serie_index) {
         e$x$opts$options[[i]]$series[[serie_index]][[names(args)[j]]] <- list()
       }
